@@ -1120,7 +1120,7 @@ class CommandPalette(SystemModalScreen[None]):
                     help_style = VisualStyle.from_styles(
                         self.get_component_styles("command-palette--help-text")
                     )
-                    yield Content.styled(hit.help, help_style)
+                    yield Content.from_rich_text(hit.help).stylize_before(help_style)
 
             prompt = Content("\n").join(build_prompt())
 
